ParseResults
============

.. currentmodule:: bioontologies.robot

.. autoclass:: ParseResults
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~ParseResults.squeeze

   .. rubric:: Methods Documentation

   .. automethod:: squeeze
